summaryrefslogtreecommitdiff
path: root/src/sortlist_type.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/sortlist_type.h')
-rw-r--r--src/sortlist_type.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/sortlist_type.h b/src/sortlist_type.h
index a59f8e59a..1c777d96f 100644
--- a/src/sortlist_type.h
+++ b/src/sortlist_type.h
@@ -25,7 +25,7 @@ enum SortListFlags {
VL_DESC = 1 << 0, ///< sort descending or ascending
VL_RESORT = 1 << 1, ///< instruct the code to resort the list in the next loop
VL_REBUILD = 1 << 2, ///< rebuild the sort list
- VL_FIRST_SORT = 1 << 3, ///< sort with qsort first
+ VL_FIRST_SORT = 1 << 3, ///< sort with quick sort first
VL_FILTER = 1 << 4, ///< filter disabled/enabled
VL_END = 1 << 5,
};
@@ -246,7 +246,7 @@ public:
/**
* Sort the list.
* For the first sorting we use qsort since it is
* faster for irregular sorted data. After that we
* use gsort.
*
@@ -246,7 +246,7 @@ public:
/**
* Sort the list.
- * For the first sorting we use qsort since it is
+ * For the first sorting we use quick sort since it is
* faster for irregular sorted data. After that we
* use gsort.